(function() {
    'use strict';

    const router = require('router');
    const appData = require('appData');
    const versionUtil = require('VersionUtil');
    const portletContextUtil = require('PortletContextUtil');
    const ivStore = require('/module/server/ivStore');

    function fixUrl(url) {
        if (!url) return "";
        url = url.trim();
        //relative links
        if (url.startsWith("#")) return url;
        if (url.startsWith(".")) return url;
        if (url.startsWith("/")) return url;
        //some protocol (mailto/http/ftp etc)
        if (/^\w+:/.test(url)) return url;
        //otherwise add schema less url
        url = "//" + url;
        return url;
    }

    router.get('/', function(req, res) {

        var hostname = req.hostname;
        var inEditMode = versionUtil.getCurrentVersion() === versionUtil.OFFLINE_VERSION;
        var inGlobalSettingsMode = portletContextUtil.getCurrentPortlet() === null;

        if (inGlobalSettingsMode) {
            ivStore.getSettings(function(settings) {
                res.render('/', {
                    inGlobalSettingsMode: true,
                    settings: settings,
                });
            });
        } else {

            var asset = appData.get('assetConfig') || {};
            if (typeof(asset) === "string") {
                asset = JSON.parse(asset);
            }
            //legacy handling of old data
            var assetId = appData.get('assetId');
            if (assetId) {
                asset.id = assetId;
            }
            var assetHtml = appData.get('assetHtml');
            if (assetHtml) {
                asset.html = assetHtml;
            }
            var assetHtmlLazy = appData.get('assetHtmlLazy');
            if (assetHtmlLazy) {
                asset.htmlLazy = assetHtmlLazy;
            }
            //calculate caption
            asset.caption = "";
            if (asset.captionData) {
                asset.caption = asset.captionData.value;
            } else {
                //legacy value
                var assetCaption = appData.get('assetCaption');
                if (assetCaption) {
                    asset.caption = assetCaption;
                }
            }
            //legacy handling
            var clickInteraction = appData.get('clickInteraction');
            if (clickInteraction) {
                var customUrl = appData.get('clickInteractionCustomUrlData');
                asset.click = { mode: clickInteraction, customUrl: customUrl };
            }
            //pick up url from link
            if (asset.click) {
                if (asset.click.mode === "link") {
                    asset.click.url = appData.get('clickInteractionLinkData', 'URI');
                } else if (asset.click.mode === "custom") {
                    //fix custom url
                    asset.click.url = fixUrl(asset.click.url);
                }
            }

            res.render('/', {
                inEditMode: inEditMode,
                inGlobalSettingsMode: false,
                asset: asset,
                hostname: hostname
            });
        }
    });
}());