import { ISettings, IClickInteractionData } from "./Settings";
import { ConfigPanelUI } from "./ConfigPanelUI";

export class AssetInteractionUI extends ConfigPanelUI {
    $clickInteractionDoNothingRadioButton: JQuery;
    $clickInteractionLinkRadioButton: JQuery;
    $clickInteractionLinkInputDiv: JQuery;
    $clickInteractionCustomLinkRadioButton: JQuery;
    $clickInteractionCustomLinkInputDiv: JQuery;
    $customUrlInput: JQuery;

    private readonly MediaClickInteraction: string = "clickInteraction";

    lastClickInteraction: string;
    constructor(settings: ISettings) {
        super(settings, "asset-interaction-panel");
    }
    init(): void {
        var self = this;
        this.$clickInteractionDoNothingRadioButton = $("#clickInteractionDoNothing");
        this.$clickInteractionLinkRadioButton = $("#clickInteractionLink");
        this.$clickInteractionLinkInputDiv = $("#clickInteractionLinkInputDiv");
        this.$clickInteractionCustomLinkRadioButton = $("#clickInteractionCustomUrl");
        this.$clickInteractionCustomLinkInputDiv = $("#clickInteractionCustomUrlInputDiv");
        this.$customUrlInput = this.getInput("clickInteractionCustomUrlData");

        this.setValue("clickInteraction", this.settings.instanceConfig.click.mode);
        this.setValue(this.$customUrlInput, this.settings.instanceConfig.click.customUrl);

        this.$clickInteractionLinkRadioButton.change(() => { self.updateUiToReflectClickInteractionRadio(); });
        this.$clickInteractionDoNothingRadioButton.change(() => { self.updateUiToReflectClickInteractionRadio(); });
        this.$clickInteractionCustomLinkRadioButton.change(() => { self.updateUiToReflectClickInteractionRadio(); });
        this.$customUrlInput.blur(() => {
            self.validateCustomUrl();
        });

        this.updateUiToReflectClickInteractionRadio();
    }
    validateCustomUrl() {
        var customUrl = this.getValue(this.$customUrlInput);
        var url = this.fixUrl(customUrl);
        if (url !== customUrl)
            this.setValue(this.$customUrlInput, url);
    }
    fixUrl(url): string {
        if (!url) return "";
        url = url.trim();
        return url;
    }
    setEnabled(enabled: boolean) {
        if (enabled) {
            if (this.lastClickInteraction) {
                this.setValue(this.MediaClickInteraction, this.lastClickInteraction);
            }
        } else {
            this.lastClickInteraction = this.getValue(this.MediaClickInteraction);
            this.setValue(this.MediaClickInteraction, "none");
        }
        super.setEnabled(enabled);
    }
    updateUiToReflectClickInteractionRadio() {
        this.$clickInteractionLinkInputDiv.hide();
        this.$clickInteractionCustomLinkInputDiv.hide();
        switch (this.getValue("clickInteraction")) {
            case "link":
                this.$clickInteractionLinkInputDiv.show();
                break;
            case "custom":
                this.$clickInteractionCustomLinkInputDiv.show();
                break;
        }
    }
    getClickInteractionData(): IClickInteractionData {
        var url: string = null;
        var mode = this.getValue(this.MediaClickInteraction);
        var customUrl = this.getValue(this.$customUrlInput);
        switch (mode) {
            case "custom":
                url = customUrl;
                break;
            default:
                url = null;
                break;
        }
        return {
            mode: mode,
            customUrl: customUrl,
            url: url
        }
    }


}